==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>IsoProject</name>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Vrh</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Dno</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Left back</source>
        <translation>Levo zadaj</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Desno zadaj</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Pred projekcijo rotiraj izbor nasproti urnemu kazalcu</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Pred projekcijo rotiraj izbor v smeri urnemu kazalcu</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation>Povečaj projekcijo na dejansko velikost (izometrična risba)</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>True scale</source>
        <translation>Dejanska velikost</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translation>&amp;Izometrična projekcija</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Projection/IsometricProjection/IsoProject/ts/IsoProject_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>IsoProject</name>
    <message>
        <location filename="../IsoProject.ui" line="+17"/>
        <source>Top</source>
        <translation>Vrh</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Bottom</source>
        <translation>Dno</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Left</source>
        <translation>Levo</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Left back</source>
        <translation>Levo zadaj</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Right back</source>
        <translation>Desno zadaj</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Rotate selection counter-clockwise before projection</source>
        <translation>Pred projekcijo rotiraj izbor nasproti urnemu kazalcu</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Rotate selection clockwise before projection</source>
        <translation>Pred projekcijo rotiraj izbor v smeri urnemu kazalcu</translation>
    </message>
    <message>
        <source>Scale projection to original size (&apos;isometric drawing&apos;)</source>
        <translation type="vanished">Povečaj projekcijo na dejansko velikost (izometrična risba)</translation>
    </message>
    <message>
        <source>True scale</source>
        <translation type="vanished">Dejanska velikost</translation>
    </message>
    <message>
        <location filename="../IsoProjectInit.js" line="+2"/>
        <source>&amp;Isometric Projection</source>
        <translation>&amp;Izometrična projekcija</translation>
    </message>
    <message>
        <location filename="../IsoProject.js" line="+50"/>
        <source>Isometric</source>
        <translation>Izometrično</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Isometric True Scale</source>
        <translation>Izometrično prave mere</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Planometric</source>
        <translation>Dimetrično</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimetric</source>
        <translation>Demetrična</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Cabinet</source>
        <translation>Kabinet</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cavalier</source>
        <translation>Kavalir</translation>
    </message>
</context>
</TS>
